import {
  type BaseFieldInfo,
  type BaseFieldItem,
  TableFieldType,
  type TableFilterItem,
  TableFilterType,
} from '@/types/Tables/table.ts'
import { reactive } from 'vue'

interface FilterInfo {
  [key: string]: TableFilterItem
}

interface ImageTag {
  id: number
  name: string
}

interface ImageMetadata {
  id: number
  name: string // 图片名称
  local_path: string // 本地地址
  gid: string // 游戏ID
  pid: string // 游戏父级ID
  wx_id: string // 微信资源ID
  image_width: number // 图片宽度
  image_height: number // 图片高度
  image_file_size: number // 图片大小
  image_type: string
  image_signature: string
  createdAt: string // 创建时间
  updatedAt: string // 更新时间
  tags: ImageTag[] // 标签列表
}

interface VideoMetadata {
  id: number
  name: string // 视频名称
  gid: string // 游戏ID
  pid: string // 游戏父级ID
  wx_id: string // 微信资源ID
  video_signature: string // 视频签名
  local_path: string // 本地路径
  createdAt: string // 创建时间
  updatedAt: string // 更新时间
}

const videoFilterInfo = reactive<FilterInfo>({
  gid: {
    label: '游戏',
    name: 'gid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  pid: {
    label: '项目',
    name: 'pid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  search: {
    label: '素材名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '名称', value: 'search' }],
  },
  tags: {
    label: '标签',
    name: 'tags',
    type: TableFilterType.Select,
    isTags: true,
    isMultiple: true,
    value: [],
    options: [],
  },
  resolution: {
    label: '分辨率',
    name: 'resolution',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  isLandscape: {
    label: '横竖屏',
    name: 'isLandscape',
    type: TableFilterType.Select,
    value: '0',
    options: [
      { label: '横屏', value: '1' },
      { label: '竖屏', value: '0' },
    ],
  },
})

const imgFilterInfo = reactive<FilterInfo>({
  gid: {
    label: '游戏',
    name: 'gid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  pid: {
    label: '项目',
    name: 'pid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  search: {
    label: '素材名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '名称', value: 'search' }],
  },
  tags: {
    label: '标签',
    name: 'tags',
    type: TableFilterType.Select,
    isTags: true,
    isMultiple: true,
    value: [],
    options: [],
  },
  isImg9: {
    label: '是否九宫格',
    name: 'isImg9',
    type: TableFilterType.Select,
    value: '0',
    options: [
      { label: '是', value: '1' },
      { label: '否', value: '0' },
    ],
  },
  resolution: {
    label: '分辨率',
    name: 'resolution',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
})

const imgFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '图片字段',
    name: 'img',
    value: [],
    children: [
      {
        label: '素材名称',
        name: 'name',
        state: true,
        fixed: true,
      },
      {
        label: '游戏ID',
        name: 'gid',
        state: true,
        fixed: false,
      },
      {
        label: '项目ID',
        name: 'pid',
        state: true,
        fixed: false,
      },
      {
        label: '预览图片',
        name: 'download',
        state: true,
        fixed: false,
        type: TableFieldType.Img,
      },
      {
        label: '分辨率',
        name: 'resolution',
        state: true,
        fixed: false,
      },
      {
        label: '创建时间',
        name: 'createdAt',
        state: true,
        fixed: true,
        sort: true,
      },
      {
        label: '更新时间',
        name: 'updatedAt',
        state: true,
        fixed: false,
      },
      {
        label: '标签',
        name: 'tag',
        type: TableFieldType.Tag,
        state: true,
        fixed: true,
      },
      {
        label: '操作',
        name: 'action',
        state: true,
        fixed: true,
      },
    ],
  },
]

const videoFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '视频字段',
    name: 'video',
    value: [],
    children: [
      {
        label: '素材名称',
        name: 'name',
        state: true,
        fixed: true,
      },
      {
        label: '游戏ID',
        name: 'gid',
        state: true,
        fixed: false,
      },
      {
        label: '项目ID',
        name: 'pid',
        state: true,
        fixed: false,
      },
      {
        label: '预览视频',
        name: 'headImgDownload',
        state: true,
        fixed: false,
        type: TableFieldType.Video,
      },
      {
        label: '分辨率',
        name: 'resolution',
        state: true,
        fixed: false,
      },
      {
        label: '创建时间',
        name: 'createdAt',

        sort: true,
        state: true,
        fixed: true,
      },
      {
        label: '更新时间',
        name: 'updatedAt',
        state: true,
        fixed: false,
      },
      {
        label: '标签',
        name: 'tag',
        type: TableFieldType.Tag,
        state: true,
        fixed: true,
      },
      {
        label: '操作',
        name: 'action',
        state: true,
        fixed: true,
      },
    ],
  },
]
export { videoFilterInfo, imgFields, videoFields, imgFilterInfo }

export type { ImageMetadata, VideoMetadata }
